//
//  AppRootController.swift
//  SampleMotion
//
//  Created by Dmitry Stepanets on 05.07.2018.
//  Copyright © 2018 Dmitry Stepanets. All rights reserved.
//

import UIKit
import Material

class AppRootController: UIViewController {
    private let menuButton = IconButton(image: Icon.menu)
    private let modalButton = RaisedButton(title: "Open Modal Controller", titleColor: Color.blue.base)
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        menuButton.addTarget(self, action: #selector(handleMenuButton), for: .touchUpInside)
        modalButton.addTarget(self, action: #selector(handleModalButton), for: .touchUpInside)
        view.addSubview(modalButton)
        view.backgroundColor = Color.lightBlue.lighten1
        view.layout(modalButton).center()
        prepareToolbar()
    }

    @objc private func handleMenuButton() {
        navigationDrawerController?.toggleLeftView()
    }
    
    @objc private func handleModalButton() {
        let modalController = ToolbarController(rootViewController: ModalViewController())
        modalController.isMotionEnabled = true
        modalController.motionTransitionType = .autoReverse(presenting: .fade)
        
        navigationDrawerController?.present(modalController, animated: true)
    }
}

private extension AppRootController {
    func prepareToolbar() {
        toolbarController?.toolbar.title = "Root View Controller"
        toolbarController?.toolbar.leftViews = [menuButton]
    }
}
